#line 2 "Tokenizer.cc"

#line 4 "Tokenizer.cc"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

/* %not-for-header */
/* %if-c-only */
/* %if-not-reentrant */
/* %endif */
/* %endif */
/* %ok-for-header */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* %if-c++-only */
    /* The c++ scanner is a mess. The FlexLexer.h header file relies on the
     * following macro. This is required in order to pass the c++-multiple-scanners
     * test in the regression suite. We get reports that it breaks inheritance.
     * We will address this in a future release of flex, or omit the C++ scanner
     * altogether.
     */
    #define yyFlexLexer TokenizerFlexLexer
/* %endif */

/* %if-c-only */
/* %endif */

#ifdef yyalloc
#define Tokenizeralloc_ALREADY_DEFINED
#else
#define yyalloc Tokenizeralloc
#endif

#ifdef yyrealloc
#define Tokenizerrealloc_ALREADY_DEFINED
#else
#define yyrealloc Tokenizerrealloc
#endif

#ifdef yyfree
#define Tokenizerfree_ALREADY_DEFINED
#else
#define yyfree Tokenizerfree
#endif

/* %if-c-only */
/* %endif */

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
/* %if-c-only */
/* %endif */

/* %if-tables-serialization */
/* %endif */
/* end standard C headers. */

/* %if-c-or-c++ */
/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* %endif */

/* begin standard C++ headers. */
/* %if-c++-only */
#include <iostream>
#include <errno.h>
#include <cstdlib>
#include <cstdio>
#include <cstring>
/* end standard C++ headers. */
/* %endif */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* %not-for-header */
/* Returned upon end-of-file. */
#define YY_NULL 0
/* %ok-for-header */

/* %not-for-header */
/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))
/* %ok-for-header */

/* %if-reentrant */
/* %endif */

/* %if-not-reentrant */

/* %endif */

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

/* %if-not-reentrant */
extern int yyleng;
/* %endif */

/* %if-c-only */
/* %if-not-reentrant */
/* %endif */
/* %endif */

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
/* %if-c-only */
/* %endif */

/* %if-c++-only */
	std::streambuf* yy_input_file;
/* %endif */

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */
/* %if-not-reentrant */
/* %endif */
/* %ok-for-header */

/* %endif */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* %if-c-only Standard (non-C++) definition */
/* %if-not-reentrant */
/* %not-for-header */
/* %ok-for-header */

/* %endif */
/* %endif */

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* %% [1.0] yytext/yyin/yyout/yy_state_type/yylineno etc. def's & init go here */
/* Begin user sect3 */
#define YY_SKIP_YYWRAP

#define FLEX_DEBUG
typedef flex_uint8_t YY_CHAR;

#define yytext_ptr yytext

#include <FlexLexer.h>

int yyFlexLexer::yywrap() { return 1; }

/* %% [1.5] DFA */

/* %if-c-only Standard (non-C++) definition */
/* %endif */

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
/* %% [2.0] code to fiddle yytext and yyleng for yymore() goes here \ */\
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
/* %% [3.0] code to copy yytext_ptr to yytext[] goes here, if %array \ */\
	(yy_c_buf_p) = yy_cp;
/* %% [4.0] data tables for the DFA and the user's section 1 definitions go here */
#define YY_NUM_RULES 98
#define YY_END_OF_BUFFER 99
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[330] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       99,   96,   95,   96,   96,   96,   96,   97,   96,   96,
       96,   96,   96,   96,   88,   89,   96,   30,   96,   32,
       35,   36,   18,   16,   33,   17,   96,   19,   85,   34,
       22,   20,   23,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   86,   86,   86,   86,   37,
       38,   21,   31,   90,   88,   92,   96,   19,   96,   96,
       96,   95,   94,    0,    0,   93,   97,    0,    0,    0,
        0,    0,    0,    7,    0,    0,   88,   89,    0,   89,
       27,    0,   87,   28,   85,   85,   85,    0,   25,   26,

       24,   86,   86,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   86,   86,   39,   86,   86,
       86,   47,   86,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   86,   86,   86,   86,   29,
       88,   92,    0,    0,   92,    0,    0,    0,   93,    0,
        0,    0,    0,    0,   13,    0,    0,    0,    0,    0,
        0,   85,   86,   86,   86,   86,   86,   86,   86,   50,
       86,   65,   45,   86,   86,   40,   86,   85,   86,   86,
       86,   86,   86,   86,   86,   86,   46,   58,   59,   63,
       85,   86,   86,   86,   86,   86,   49,   86,   86,   64,

       51,   86,   86,   86,    0,    0,    0,   91,    0,    0,
        0,    5,   11,    0,    0,    0,    0,    0,    0,    1,
        0,   85,   53,   86,   52,   54,   79,   56,   61,   86,
       66,   86,   86,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   80,   86,   42,   57,   55,   86,
       43,   86,   86,   41,    0,    0,    0,    0,    0,   12,
        6,    8,    0,    0,   83,   86,   44,   60,   67,   86,
       86,   86,   86,   86,   86,   86,   86,   48,   86,   86,
       69,   86,   62,   82,    0,    0,    0,    4,    0,   10,
       14,    9,    0,   86,   86,   86,   86,   75,   86,   86,

       70,   68,   86,   86,   81,    0,    2,   84,   78,   86,
       73,   86,   77,   72,   71,    0,    0,   86,   76,    0,
        0,   74,    0,    0,    0,    3,    0,   15,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    7,    1,    1,    8,    1,    9,
       10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
       19,   19,   19,   19,   19,   19,   19,   20,    1,   21,
       22,   23,    1,   24,   25,   26,   27,   28,   29,   30,
       31,   32,   33,   34,   34,   35,   36,   37,   38,   39,
       40,   41,   42,   43,   44,   45,   46,   47,   48,   34,
       49,   50,   51,   52,   34,    1,   53,   54,   55,   56,

       57,   58,   59,   60,   61,   34,   34,   62,   63,   64,
       65,   66,   67,   68,   69,   70,   71,   72,   73,   74,
       75,   34,   76,   77,   78,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[79] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    2,    2,    2,    1,
        1,    1,    1,    1,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    1,    1,
        1,    1,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    1,    1,    1
    } ;

static const flex_int16_t yy_base[335] =
    {   0,
        0,    3,   25,   85,  147,    0,    6,   14,    9,   17,
      617,  711,  711,  613,  502,   12,   19,  711,  566,    5,
        8,    0,   10,    8,  558,   28,  541,  508,  499,  472,
      711,  711,  711,  711,  711,  711,   33,  711,   79,  711,
      347,  342,  340,  199,    1,   73,   28,   32,   66,   50,
        0,   68,  198,  205,  206,  199,  240,  207,   61,  711,
      711,  711,  238,  711,  283,  711,  301,  276,  197,  286,
      223,  711,  711,   13,  226,  137,  711,   82,   84,    2,
       89,  193,  204,  263,  219,  212,  127,   74,  123,  119,
      711,  103,  711,  711,  277,  295,  303,  323,  711,  711,

      711,    0,  212,  211,  220,  272,  244,  262,  265,  274,
      278,  287,  289,  294,  300,  298,  308,  316,  350,  313,
      328,    0,  323,  310,  321,  333,  326,  326,  343,  326,
      327,  349,  332,  337,  347,  350,  344,  356,  369,  711,
      421,  711,   87,   64,  711,  121,  425,  428,   59,  373,
      371,  382,  405,  378,  711,  383,  389,  386,  404,  435,
      330,  438,  400,  421,  413,  414,  423,  416,  425,    0,
      429,  437,    0,  425,  430,    0,  434,    0,  430,  434,
      437,  436,  432,  432,  448,  445,   30,    0,    0,    0,
        0,  446,  448,  447,  459,  454,    0,  453,  456,    0,

        0,  475,  466,  469,  130,  398,  511,  711,   43,   26,
      482,  484,  488,  486,  492,  484,  496,  500,  487,  711,
      517,  523,    0,  489,    0,    0,    0,    0,    0,  501,
        0,  514,  504,  523,  512,  517,  517,  534,  520,  523,
      520,  530,    6,  540,    0,  540,    0,    0,    0,  533,
        0,  546,  545,    0,  582,  546,  552,  551,  550,  711,
      711,  711,  562,  566,    0,  569,    0,    0,    0,  574,
      569,  564,  573,  567,  575,  579,  587,    0,  585,  586,
        0,  584,    0,    0,  621,  642,  645,  711,  602,  711,
      711,  711,  601,  604,  588,  604,  590,    0,  613,  622,

        0,    0,  622,  623,    0,  614,  617,    0,    0,  634,
        0,  631,    0,    0,    0,  626,  641,  631,    0,  624,
      627,    0,  646,  640,  633,  711,  633,  711,  711,  702,
      704,    0,  706,  708
    } ;

static const flex_int16_t yy_def[335] =
    {   0,
      330,  330,  330,  330,  329,    5,    5,    5,  330,  330,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  331,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  331,  329,  329,  329,  329,  329,  329,  329,  329,

      329,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  329,
      329,  329,  329,  329,  329,  333,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,

      332,  332,  332,  332,  333,  333,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  334,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  334,  334,  334,  329,  329,  329,
      329,  329,  329,  332,  332,  332,  332,  332,  332,  332,

      332,  332,  332,  332,  332,  329,  329,  332,  332,  332,
      332,  332,  332,  332,  332,  329,  329,  332,  332,  329,
      329,  332,  329,  329,  329,  329,  329,  329,    0,  329,
      329,  329,  329,  329
    } ;

static const flex_int16_t yy_nxt[790] =
    {   0,
      329,  102,   13,   14,   16,   13,   14,   65,   66,   67,
       70,   66,   67,   74,   74,   65,   66,   67,   70,   66,
       67,   68,  278,   15,   71,   76,   17,   18,   19,   68,
       88,   89,   71,   78,   79,   75,   75,   83,  107,   84,
       86,  255,   80,  152,   81,  208,   85,  243,   82,   95,
       95,   95,   20,   21,   22,   69,  111,   23,   69,   24,
      149,   78,   79,   69,   83,  107,   69,   84,   86,   80,
      152,   81,  112,   85,  117,   82,   88,   89,  113,  146,
       20,   21,   22,   12,  111,   23,   24,   18,   19,  142,
      114,   12,  139,   96,   73,   97,   97,   97,  108,  112,

      115,  109,  117,  116,  118,  113,   98,   98,   93,  119,
      110,  150,   20,   21,   22,  151,  153,   23,  114,   24,
      139,   88,   89,  142,  206,   88,  108,  115,   87,  109,
      116,  118,  142,  206,   98,   98,  119,  110,  149,  150,
       20,   21,   22,  151,  153,   23,   24,   12,   25,   26,
       27,   28,   29,   12,   30,   31,   32,   33,   34,   35,
       36,   37,   38,   39,   39,   39,   40,   41,   42,   43,
       12,   44,   45,   46,   47,   48,   49,   50,   51,   52,
       51,   53,   54,   55,   51,   51,   51,   56,   57,   58,
       51,   51,   59,   51,   51,   60,   12,   61,   62,   44,

       45,   46,   47,   48,   49,   50,   51,   52,   53,   54,
       55,   51,   51,   51,   56,   57,   58,   51,   51,   59,
       51,   51,   12,   63,   64,  103,  120,  129,  121,  124,
      127,  136,   76,  154,  122,  123,  130,  125,  146,  104,
      105,  106,  126,  128,  155,  158,  147,  137,  159,  163,
      138,  164,  165,  103,  120,  129,  121,  124,  127,  136,
      154,  122,  123,  130,  131,  125,  104,  105,  106,  126,
      128,  155,  132,  158,  137,  159,  163,  138,  164,  133,
      165,  167,  134,  135,  141,  142,  143,  148,  142,  143,
      156,  146,  131,   95,   95,   95,  166,  169,  144,  157,

      132,  144,  168,  145,  160,  160,  133,  171,  167,  134,
      135,   95,   95,   95,  140,  170,  172,   96,  156,   97,
       97,   97,  160,  160,  166,  169,  157,  173,  174,  168,
       98,   98,  160,  160,  161,  171,  161,  175,  176,  162,
      162,  162,  170,  177,  172,  178,  162,  162,  162,  185,
      160,  160,  186,  187,  173,  174,  188,  189,   98,   98,
      190,  101,  191,  100,  175,  176,  192,  193,   99,  194,
      177,  195,  198,  178,  179,  180,  185,  199,  181,  196,
      186,  187,  200,  188,  189,  197,  201,  202,  190,  191,
      182,  183,  184,  192,  203,  193,  194,  204,  195,  198,

      142,  206,  179,  180,  199,  211,  181,  196,  212,  200,
      213,  217,  197,  201,  202,  216,  218,  182,  183,  184,
      219,  203,  141,  142,  143,  204,  207,  208,  209,  148,
      142,  143,  220,  211,  214,  212,  144,  215,  213,  217,
      210,  223,  216,  144,  218,  224,  221,  219,  221,  225,
      226,  222,  222,  222,  162,  162,  162,  227,  228,  229,
      220,  230,  214,  231,  238,  215,  232,  233,  223,  234,
      235,  236,  237,  224,  239,  240,  225,  226,  241,   94,
      242,  244,  245,  246,  227,  228,  229,  247,  250,  230,
      248,  231,  238,  232,  233,  249,  234,  235,  236,  237,

      253,  239,  240,  251,   93,  254,  241,  242,  244,  245,
      246,  252,  207,  208,  209,  247,  250,  248,  256,  257,
      258,  260,  249,  259,  261,  262,  210,  253,  263,   91,
      264,  251,  254,  222,  222,  222,  265,  266,  252,  222,
      222,  222,  267,   90,  268,  256,  257,  269,  258,  260,
      259,  261,  270,  262,  271,  272,  263,  264,  273,   87,
      274,  275,  276,  265,  266,  277,  279,  281,   77,  282,
      267,  268,  283,  284,  288,  269,  289,   73,  280,  270,
      290,  271,  272,  286,  208,  287,  273,  274,  275,  276,
      291,  292,  277,  293,  279,  281,  282,  294,  295,  299,

      283,  284,  288,  296,  289,  280,  297,  298,  290,  300,
      301,  302,  303,  304,  305,   72,  329,  291,  329,  292,
      329,  293,  286,  208,  287,  294,  295,  299,  306,  307,
      296,  308,  310,  297,  298,  309,  300,  311,  301,  302,
      303,  304,  305,  286,  208,  287,  286,  208,  287,  312,
      313,  314,  315,  329,  316,  317,  306,  307,  318,  308,
      310,  319,  309,  320,  311,  321,  329,  322,  323,  324,
      325,  326,  329,  327,  328,  329,  312,  329,  313,  314,
      315,  316,  317,  329,  329,  329,  318,  329,  329,  319,
      320,  329,  329,  321,  322,  323,  324,  329,  325,  326,

      327,  328,   12,   12,   92,   92,  205,  205,  285,  285,
       11,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329
    } ;

static const flex_int16_t yy_chk[790] =
    {   0,
        0,  332,    1,    1,    2,    2,    2,    7,    7,    7,
        9,    9,    9,   16,   74,    8,    8,    8,   10,   10,
       10,    7,  243,    1,    9,   17,    2,    3,    3,    8,
       26,   26,   10,   20,   21,   16,   74,   22,   45,   23,
       24,  210,   21,   80,   21,  209,   23,  187,   21,   37,
       37,   37,    3,    3,    3,    7,   47,    3,    9,    3,
      149,   20,   21,    8,   22,   45,   10,   23,   24,   21,
       80,   21,   48,   23,   50,   21,   88,   88,   48,  144,
        3,    3,    3,    7,   47,    3,    3,    4,    4,  143,
       49,    8,   59,   39,   17,   39,   39,   39,   46,   48,

       49,   46,   50,   49,   52,   48,   39,   39,   92,   52,
       46,   78,    4,    4,    4,   79,   81,    4,   49,    4,
       59,   90,   90,  146,  146,   89,   46,   49,   87,   46,
       49,   52,  205,  205,   39,   39,   52,   46,   76,   78,
        4,    4,    4,   79,   81,    4,    4,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,

        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,   44,   53,   56,   53,   54,
       55,   58,   75,   82,   53,   53,   56,   54,   71,   44,
       44,   44,   54,   55,   83,   85,   69,   58,   86,  103,
       58,  104,  105,   44,   53,   56,   53,   54,   55,   58,
       82,   53,   53,   56,   57,   54,   44,   44,   44,   54,
       55,   83,   57,   85,   58,   86,  103,   58,  104,   57,
      105,  107,   57,   57,   65,   65,   65,   70,   70,   70,
       84,   68,   57,   95,   95,   95,  106,  109,   65,   84,

       57,   70,  108,   67,   95,   95,   57,  111,  107,   57,
       57,   96,   96,   96,   63,  110,  112,   97,   84,   97,
       97,   97,   96,   96,  106,  109,   84,  113,  114,  108,
       97,   97,   95,   95,   98,  111,   98,  115,  116,   98,
       98,   98,  110,  117,  112,  118,  161,  161,  161,  120,
       96,   96,  121,  123,  113,  114,  124,  125,   97,   97,
      126,   43,  127,   42,  115,  116,  128,  129,   41,  130,
      117,  131,  133,  118,  119,  119,  120,  134,  119,  132,
      121,  123,  135,  124,  125,  132,  136,  137,  126,  127,
      119,  119,  119,  128,  138,  129,  130,  139,  131,  133,

      206,  206,  119,  119,  134,  150,  119,  132,  151,  135,
      152,  156,  132,  136,  137,  154,  157,  119,  119,  119,
      158,  138,  141,  141,  141,  139,  147,  147,  147,  148,
      148,  148,  159,  150,  153,  151,  141,  153,  152,  156,
      147,  163,  154,  148,  157,  164,  160,  158,  160,  165,
      166,  160,  160,  160,  162,  162,  162,  167,  168,  169,
      159,  171,  153,  172,  182,  153,  174,  175,  163,  177,
      179,  180,  181,  164,  183,  184,  165,  166,  185,   30,
      186,  192,  193,  194,  167,  168,  169,  195,  199,  171,
      196,  172,  182,  174,  175,  198,  177,  179,  180,  181,

      203,  183,  184,  202,   29,  204,  185,  186,  192,  193,
      194,  202,  207,  207,  207,  195,  199,  196,  211,  212,
      213,  215,  198,  214,  216,  217,  207,  203,  218,   28,
      219,  202,  204,  221,  221,  221,  224,  230,  202,  222,
      222,  222,  232,   27,  233,  211,  212,  234,  213,  215,
      214,  216,  235,  217,  236,  237,  218,  219,  238,   25,
      239,  240,  241,  224,  230,  242,  244,  246,   19,  250,
      232,  233,  252,  253,  256,  234,  257,   15,  244,  235,
      258,  236,  237,  255,  255,  255,  238,  239,  240,  241,
      259,  263,  242,  264,  244,  246,  250,  266,  270,  274,

      252,  253,  256,  271,  257,  244,  272,  273,  258,  275,
      276,  277,  279,  280,  282,   14,   11,  259,    0,  263,
        0,  264,  285,  285,  285,  266,  270,  274,  289,  293,
      271,  294,  296,  272,  273,  295,  275,  297,  276,  277,
      279,  280,  282,  286,  286,  286,  287,  287,  287,  299,
      300,  303,  304,    0,  306,  307,  289,  293,  310,  294,
      296,  312,  295,  316,  297,  317,    0,  318,  320,  321,
      323,  324,    0,  325,  327,    0,  299,    0,  300,  303,
      304,  306,  307,    0,    0,    0,  310,    0,    0,  312,
      316,    0,    0,  317,  318,  320,  321,    0,  323,  324,

      325,  327,  330,  330,  331,  331,  333,  333,  334,  334,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329
    } ;

static const flex_int16_t yy_rule_linenum[98] =
    {   0,
       68,   69,   70,   71,   72,   73,   74,   75,   76,   77,
       78,   79,   80,   81,   82,   84,   85,   86,   87,   88,
       89,   90,   91,   92,   93,   94,   95,   97,   98,   99,
      101,  102,  104,  105,  107,  108,  109,  110,  111,  112,
      113,  114,  116,  117,  119,  120,  121,  122,  123,  124,
      125,  126,  127,  128,  129,  130,  131,  132,  133,  134,
      135,  136,  137,  138,  139,  140,  141,  142,  143,  144,
      145,  146,  148,  149,  150,  151,  152,  153,  155,  156,
      157,  158,  159,  161,  163,  168,  173,  178,  179,  180,
      182,  183,  185,  186,  187,  192,  193

    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "Tokenizer.ll"
/* -*- C++ -*- */
/*
 * Copyright © 2019-2021 Dynare Team
 *
 * This file is part of Dynare.
 *
 * Dynare is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Dynare is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 */
#line 22 "Tokenizer.ll"
#include "Driver.hh"

// Announce to Flex the prototype we want for lexing function
#define YY_DECL                                                \
  Tokenizer::parser::token_type                                \
  TokenizerFlex::lex(Tokenizer::parser::semantic_type *yylval, \
                     Tokenizer::parser::location_type *yylloc, \
                     macro::Driver &driver)

// Shortcut to access tokens defined by Bison
using token = Tokenizer::parser::token;

/* By default yylex returns int, we use token_type.
   Unfortunately yyterminate by default returns 0, which is
   not of token_type.  */
#define yyterminate() return Tokenizer::parser::token_type (0);
#line 822 "Tokenizer.cc"
#define YY_NO_INPUT 1

#line 52 "Tokenizer.ll"
  // Increments location counter for every token read
  #define YY_USER_ACTION location_increment(yylloc, yytext);
#line 828 "Tokenizer.cc"
#line 829 "Tokenizer.cc"

#define INITIAL 0
#define directive 1
#define eval 2
#define expr 3
#define end_line 4

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
#include <unistd.h>
/* %endif */
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* %if-c-only Reentrant structure and macros (non-C++). */
/* %if-reentrant */
/* %if-c-only */
/* %endif */
/* %if-reentrant */
/* %endif */
/* %endif End reentrant structures and macros. */
/* %if-bison-bridge */
/* %endif */
/* %not-for-header */
/* %ok-for-header */

/* %endif */

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */
/* %ok-for-header */

/* %endif */
#endif

/* %if-c-only */
/* %endif */

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* %if-c-only Standard (non-C++) definition */
/* %endif */
/* %if-c++-only C++ definition */
#define ECHO LexerOutput( yytext, yyleng )
/* %endif */
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
/* %% [5.0] fread()/read() definition of YY_INPUT goes here unless we're doing C++ \ */\
\
/* %if-c++-only C++ definition \ */\
	if ( (int)(result = LexerInput( (char *) buf, max_size )) < 0 ) \
		YY_FATAL_ERROR( "input in flex scanner failed" );
/* %endif */

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
/* %if-c-only */
/* %endif */
/* %if-c++-only */
#define YY_FATAL_ERROR(msg) LexerError( msg )
/* %endif */
#endif

/* %if-tables-serialization structures and prototypes */
/* %not-for-header */
/* %ok-for-header */

/* %not-for-header */
/* %tables-yydmap generated elements */
/* %endif */
/* end tables serialization structures and prototypes */

/* %ok-for-header */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
/* %if-c-only Standard (non-C++) definition */
/* %endif */
/* %if-c++-only C++ definition */
#define YY_DECL int yyFlexLexer::yylex()
/* %endif */
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

/* %% [6.0] YY_RULE_SETUP definition goes here */
#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/* %not-for-header */
/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
/* %if-c-only */
/* %endif */
/* %if-c++-only */
			yyin.rdbuf(std::cin.rdbuf());
/* %endif */

		if ( ! yyout )
/* %if-c-only */
/* %endif */
/* %if-c++-only */
			yyout.rdbuf(std::cout.rdbuf());
/* %endif */

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
/* %% [7.0] user's declarations go here */
#line 60 "Tokenizer.ll"

#line 62 "Tokenizer.ll"
 /* Code put at the beginning of yylex() */

  // Reset location before reading token
  yylloc->step();


#line 1037 "Tokenizer.cc"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
/* %% [8.0] yymore()-related code goes here */
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

/* %% [9.0] code to set up and find next match goes here */
		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 330 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 329 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
/* %% [10.0] code to find the action number goes here */
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

/* %% [11.0] code for yylineno update goes here */

do_action:	/* This label is used only to access EOF actions. */

/* %% [12.0] debug code goes here */
		if ( yy_flex_debug )
			{
			if ( yy_act == 0 )
				std::cerr << "--scanner backing up\n";
			else if ( yy_act < 98 )
				std::cerr << "--accepting rule at line " << yy_rule_linenum[yy_act] <<
				         "(\"" << yytext << "\")\n";
			else if ( yy_act == 98 )
				std::cerr << "--accepting default rule (\"" << yytext << "\")\n";
			else if ( yy_act == 99 )
				std::cerr << "--(end of buffer or a NUL)\n";
			else
				std::cerr << "--EOF (start condition " << YY_START << ")\n";
			}

		switch ( yy_act )
	{ /* beginning of action switch */
/* %% [13.0] actions go here */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 68 "Tokenizer.ll"
{ BEGIN(expr); return token::LINE; }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 69 "Tokenizer.ll"
{ BEGIN(expr); return token::INCLUDE; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 70 "Tokenizer.ll"
{ BEGIN(expr); return token::INCLUDEPATH; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 71 "Tokenizer.ll"
{ BEGIN(expr); return token::DEFINE; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 72 "Tokenizer.ll"
{ BEGIN(expr); return token::D_ECHO; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 73 "Tokenizer.ll"
{ BEGIN(expr); return token::ERROR; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 74 "Tokenizer.ll"
{ BEGIN(expr); return token::IF; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 75 "Tokenizer.ll"
{ BEGIN(expr); return token::IFDEF; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 76 "Tokenizer.ll"
{ BEGIN(expr); return token::IFNDEF; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 77 "Tokenizer.ll"
{ BEGIN(expr); return token::ELSEIF; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 78 "Tokenizer.ll"
{ BEGIN(end_line); return token::ELSE; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 79 "Tokenizer.ll"
{ BEGIN(end_line); return token::ENDIF; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 80 "Tokenizer.ll"
{ BEGIN(expr); return token::FOR; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 81 "Tokenizer.ll"
{ BEGIN(end_line); return token::ENDFOR; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 82 "Tokenizer.ll"
{ BEGIN(expr); return token::ECHOMACROVARS; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 84 "Tokenizer.ll"
{ return token::PLUS; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 85 "Tokenizer.ll"
{ return token::MINUS; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 86 "Tokenizer.ll"
{ return token::TIMES; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 87 "Tokenizer.ll"
{ return token::DIVIDE; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 88 "Tokenizer.ll"
{ return token::EQUAL; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 89 "Tokenizer.ll"
{ return token::POWER; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 90 "Tokenizer.ll"
{ return token::LESS; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 91 "Tokenizer.ll"
{ return token::GREATER; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 92 "Tokenizer.ll"
{ return token::GREATER_EQUAL; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 93 "Tokenizer.ll"
{ return token::LESS_EQUAL; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 94 "Tokenizer.ll"
{ return token::EQUAL_EQUAL; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 95 "Tokenizer.ll"
{ return token::NOT_EQUAL; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 97 "Tokenizer.ll"
{ return token::AND; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 98 "Tokenizer.ll"
{ return token::OR; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 99 "Tokenizer.ll"
{ return token::NOT; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 101 "Tokenizer.ll"
{ return token::UNION; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 102 "Tokenizer.ll"
{ return token::INTERSECTION; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 104 "Tokenizer.ll"
{ return token::COMMA; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 105 "Tokenizer.ll"
{ return token::COLON; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 107 "Tokenizer.ll"
{ return token::LPAREN; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 108 "Tokenizer.ll"
{ return token::RPAREN; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 109 "Tokenizer.ll"
{ return token::LBRACKET; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 110 "Tokenizer.ll"
{ return token::RBRACKET; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 111 "Tokenizer.ll"
{ return token::IN; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 112 "Tokenizer.ll"
{ return token::FOR; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 113 "Tokenizer.ll"
{ return token::WHEN; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 114 "Tokenizer.ll"
{ return token::SAVE; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 116 "Tokenizer.ll"
{ return token::TRUE; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 117 "Tokenizer.ll"
{ return token::FALSE; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 119 "Tokenizer.ll"
{ return token::EXP; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 120 "Tokenizer.ll"
{ return token::LOG; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 121 "Tokenizer.ll"
{ return token::LN; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 122 "Tokenizer.ll"
{ return token::LOG10; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 123 "Tokenizer.ll"
{ return token::SIN; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 124 "Tokenizer.ll"
{ return token::COS; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 125 "Tokenizer.ll"
{ return token::TAN; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 126 "Tokenizer.ll"
{ return token::ATAN; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 127 "Tokenizer.ll"
{ return token::ACOS; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 128 "Tokenizer.ll"
{ return token::ATAN; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 129 "Tokenizer.ll"
{ return token::SQRT; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 130 "Tokenizer.ll"
{ return token::CBRT; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 131 "Tokenizer.ll"
{ return token::SIGN; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 132 "Tokenizer.ll"
{ return token::MAX; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 133 "Tokenizer.ll"
{ return token::MIN; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 134 "Tokenizer.ll"
{ return token::FLOOR; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 135 "Tokenizer.ll"
{ return token::CEIL; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 136 "Tokenizer.ll"
{ return token::TRUNC; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 137 "Tokenizer.ll"
{ return token::MOD; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 138 "Tokenizer.ll"
{ return token::SUM; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 139 "Tokenizer.ll"
{ return token::ERF; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 140 "Tokenizer.ll"
{ return token::ERFC; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 141 "Tokenizer.ll"
{ return token::GAMMA; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 142 "Tokenizer.ll"
{ return token::LGAMMA; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 143 "Tokenizer.ll"
{ return token::ROUND; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 144 "Tokenizer.ll"
{ return token::LENGTH; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 145 "Tokenizer.ll"
{ return token::NORMPDF; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 146 "Tokenizer.ll"
{ return token::NORMCDF; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 148 "Tokenizer.ll"
{ return token::ISEMPTY; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 149 "Tokenizer.ll"
{ return token::ISBOOLEAN; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 150 "Tokenizer.ll"
{ return token::ISREAL; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 151 "Tokenizer.ll"
{ return token::ISSTRING; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 152 "Tokenizer.ll"
{ return token::ISTUPLE; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 153 "Tokenizer.ll"
{ return token::ISARRAY; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 155 "Tokenizer.ll"
{ return token::BOOL; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 156 "Tokenizer.ll"
{ return token::REAL; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 157 "Tokenizer.ll"
{ return token::STRING; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 158 "Tokenizer.ll"
{ return token::TUPLE; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 159 "Tokenizer.ll"
{ return token::ARRAY; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 161 "Tokenizer.ll"
{ return token::DEFINED; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 163 "Tokenizer.ll"
{
  yylval->build<string>(yytext);
  return token::NUMBER;
}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 168 "Tokenizer.ll"
{
  yylval->build<string>(yytext);
  return token::NAME;
}
	YY_BREAK
case 87:
/* rule 87 can match eol */
YY_RULE_SETUP
#line 173 "Tokenizer.ll"
{
  yylval->build<string>(yytext + 1).pop_back();
  return token::QUOTED_STRING;
}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 178 "Tokenizer.ll"
{ }
	YY_BREAK
case 89:
/* rule 89 can match eol */
YY_RULE_SETUP
#line 179 "Tokenizer.ll"
{ }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 180 "Tokenizer.ll"
{ BEGIN(INITIAL); return token::END_EVAL; }
	YY_BREAK
case 91:
/* rule 91 can match eol */
YY_RULE_SETUP
#line 182 "Tokenizer.ll"
{ yylloc->step(); }
	YY_BREAK
case 92:
/* rule 92 can match eol */
YY_RULE_SETUP
#line 183 "Tokenizer.ll"
{ BEGIN(INITIAL); return token::EOL; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 185 "Tokenizer.ll"
{ BEGIN(directive); }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 186 "Tokenizer.ll"
{ BEGIN(eval); return token::BEGIN_EVAL; }
	YY_BREAK
case 95:
/* rule 95 can match eol */
YY_RULE_SETUP
#line 187 "Tokenizer.ll"
{ return token::EOL; }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
#line 188 "Tokenizer.ll"
{ yyterminate(); }
	YY_BREAK
case YY_STATE_EOF(directive):
case YY_STATE_EOF(expr):
case YY_STATE_EOF(eval):
case YY_STATE_EOF(end_line):
#line 190 "Tokenizer.ll"
{ driver.error(*yylloc, "unexpected end of file"); }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 192 "Tokenizer.ll"
{ yylval->build<string>(yytext); return token::TEXT; }
	YY_BREAK
case 97:
/* rule 97 can match eol */
YY_RULE_SETUP
#line 193 "Tokenizer.ll"
{ driver.error(*yylloc, "character unrecognized by lexer"); }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 195 "Tokenizer.ll"
ECHO;
	YY_BREAK
#line 1629 "Tokenizer.cc"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
/* %if-c-only */
/* %endif */
/* %if-c++-only */
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin.rdbuf();
/* %endif */
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
/* %% [14.0] code to do back-up for compressed tables and set up yy_cp goes here */
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */
/* %ok-for-header */

/* %if-c++-only */
/* %not-for-header */
/* The contents of this function are C++ specific, so the () macro is not used.
 * This constructor simply maintains backward compatibility.
 * DEPRECATED
 */
yyFlexLexer::yyFlexLexer( std::istream* arg_yyin, std::ostream* arg_yyout ):
	yyin(arg_yyin ? arg_yyin->rdbuf() : std::cin.rdbuf()),
	yyout(arg_yyout ? arg_yyout->rdbuf() : std::cout.rdbuf())
{
	ctor_common();
}

/* The contents of this function are C++ specific, so the () macro is not used.
 */
yyFlexLexer::yyFlexLexer( std::istream& arg_yyin, std::ostream& arg_yyout ):
	yyin(arg_yyin.rdbuf()),
	yyout(arg_yyout.rdbuf())
{
	ctor_common();
}

/* The contents of this function are C++ specific, so the () macro is not used.
 */
void yyFlexLexer::ctor_common()
{
	yy_c_buf_p = 0;
	yy_init = 0;
	yy_start = 0;
	yy_flex_debug = 0;
	yylineno = 1;	// this will only get updated if %option yylineno

	yy_did_buffer_switch_on_eof = 0;

	yy_looking_for_trail_begin = 0;
	yy_more_flag = 0;
	yy_more_len = 0;
	yy_more_offset = yy_prev_more_offset = 0;

	yy_start_stack_ptr = yy_start_stack_depth = 0;
	yy_start_stack = NULL;

	yy_buffer_stack = NULL;
	yy_buffer_stack_top = 0;
	yy_buffer_stack_max = 0;

	yy_state_buf = 0;

}

/* The contents of this function are C++ specific, so the () macro is not used.
 */
yyFlexLexer::~yyFlexLexer()
{
	delete [] yy_state_buf;
	yyfree( yy_start_stack  );
	yy_delete_buffer( YY_CURRENT_BUFFER );
	yyfree( yy_buffer_stack  );
}

/* The contents of this function are C++ specific, so the () macro is not used.
 */
void yyFlexLexer::switch_streams( std::istream& new_in, std::ostream& new_out )
{
	// was if( new_in )
	yy_delete_buffer( YY_CURRENT_BUFFER );
	yy_switch_to_buffer( yy_create_buffer( new_in, YY_BUF_SIZE  ) );

	// was if( new_out )
	yyout.rdbuf(new_out.rdbuf());
}

/* The contents of this function are C++ specific, so the () macro is not used.
 */
void yyFlexLexer::switch_streams( std::istream* new_in, std::ostream* new_out )
{
	if( ! new_in ) {
		new_in = &yyin;
	}

	if ( ! new_out ) {
		new_out = &yyout;
	}

	switch_streams(*new_in, *new_out);
}

#ifdef YY_INTERACTIVE
int yyFlexLexer::LexerInput( char* buf, int /* max_size */ )
#else
int yyFlexLexer::LexerInput( char* buf, int max_size )
#endif
{
	if ( yyin.eof() || yyin.fail() )
		return 0;

#ifdef YY_INTERACTIVE
	yyin.get( buf[0] );

	if ( yyin.eof() )
		return 0;

	if ( yyin.bad() )
		return -1;

	return 1;

#else
	(void) yyin.read( buf, max_size );

	if ( yyin.bad() )
		return -1;
	else
		return yyin.gcount();
#endif
}

void yyFlexLexer::LexerOutput( const char* buf, int size )
{
	(void) yyout.write( buf, size );
}
/* %ok-for-header */

/* %endif */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
int yyFlexLexer::yy_get_next_buffer()
/* %endif */
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

/* %if-c-only */
/* %not-for-header */
/* %endif */
/* %if-c++-only */
    yy_state_type yyFlexLexer::yy_get_previous_state()
/* %endif */
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
/* %% [15.0] code to get the start state into yy_current_state goes here */
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
/* %% [16.0] code to find the next state goes here */
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 330 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    yy_state_type yyFlexLexer::yy_try_NUL_trans( yy_state_type yy_current_state )
/* %endif */
{
	int yy_is_jam;
    /* %% [17.0] code to find the next state, and perhaps do backing up, goes here */
	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 330 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 329);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yyunput( int c, char* yy_bp)
/* %endif */
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

/* %% [18.0] update yylineno here */

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}
/* %if-c-only */
/* %endif */
#endif

/* %if-c-only */
/* %endif */
/* %if-c++-only */
    int yyFlexLexer::yyinput()
/* %endif */
{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

/* %% [19.0] update BOL and yylineno */
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
/* %if-c-only */
/* %endif */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yyrestart( std::istream& input_file )
/* %endif */
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/* %if-c++-only */
/** Delegate to the new version that takes an istream reference.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
void yyFlexLexer::yyrestart( std::istream* input_file )
{
	if( ! input_file ) {
		input_file = &yyin;
	}
	yyrestart( *input_file );
}
/* %endif */

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_switch_to_buffer( YY_BUFFER_STATE new_buffer )
/* %endif */
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_load_buffer_state()
/* %endif */
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
/* %if-c-only */
/* %endif */
/* %if-c++-only */
	yyin.rdbuf(YY_CURRENT_BUFFER_LVALUE->yy_input_file);
/* %endif */
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    YY_BUFFER_STATE yyFlexLexer::yy_create_buffer( std::istream& file, int size )
/* %endif */
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/* %if-c++-only */
/** Delegate creation of buffers to the new version that takes an istream reference.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
	YY_BUFFER_STATE yyFlexLexer::yy_create_buffer( std::istream* file, int size )
{
	return yy_create_buffer( *file, size );
}
/* %endif */

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_delete_buffer( YY_BUFFER_STATE b )
/* %endif */
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_init_buffer( YY_BUFFER_STATE b, std::istream& file )
/* %endif */

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

/* %if-c-only */
/* %endif */
/* %if-c++-only */
	b->yy_input_file = file.rdbuf();
/* %endif */
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

/* %if-c-only */
/* %endif */
/* %if-c++-only */
	b->yy_is_interactive = 0;
/* %endif */
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_flush_buffer( YY_BUFFER_STATE b )
/* %endif */
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/* %if-c-or-c++ */
/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
void yyFlexLexer::yypush_buffer_state (YY_BUFFER_STATE new_buffer)
/* %endif */
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}
/* %endif */

/* %if-c-or-c++ */
/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
void yyFlexLexer::yypop_buffer_state (void)
/* %endif */
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}
/* %endif */

/* %if-c-or-c++ */
/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
void yyFlexLexer::yyensure_buffer_stack(void)
/* %endif */
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}
/* %endif */

/* %if-c-only */
/* %endif */

/* %if-c-only */
/* %endif */

/* %if-c-only */
/* %endif */

/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_push_state( int _new_state )
/* %endif */
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_size_t) (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) yyalloc( new_size  );

		else
			(yy_start_stack) = (int *) yyrealloc(
					(void *) (yy_start_stack), new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(_new_state);
}

/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_pop_state()
/* %endif */
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

/* %if-c-only */
/* %endif */
/* %if-c++-only */
    int yyFlexLexer::yy_top_state()
/* %endif */
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

/* %if-c-only */
/* %endif */
/* %if-c++-only */
void yyFlexLexer::LexerError( const char* msg )
{
    	std::cerr << msg << std::endl;
	exit( YY_EXIT_FAILURE );
}
/* %endif */

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/* %if-c-only */
/* %if-reentrant */
/* %endif */
/* %if-reentrant */
/* %endif */
/* %endif */

/* %if-reentrant */
/* %if-bison-bridge */
/* %endif */
/* %endif if-c-only */

/* %if-c-only */
/* %endif */

/* %if-c-only SNIP! this currently causes conflicts with the c++ scanner */
/* %if-reentrant */
/* %endif */
/* %endif */

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

/* %if-tables-serialization definitions */
/* %define-yytables   The name for this specific scanner's tables. */
#define YYTABLES_NAME "yytables"
/* %endif */

/* %ok-for-header */

#line 195 "Tokenizer.ll"


void
TokenizerFlex::location_increment(Tokenizer::parser::location_type *yylloc, const char *yytext)
{
  while (*yytext != 0)
    if (*yytext++ == '\n')
      yylloc->lines(1);
    else
      yylloc->columns(1);
}

/* This implementation of TokenizerFlexLexer::yylex() is required to fill the
 * vtable of the class TokenizerFlexLexer. We define the scanner's main yylex
 * function via YY_DECL to reside in the TokenizerFlex class instead. */

#ifdef yylex
# undef yylex
#endif

int
TokenizerFlexLexer::yylex()
{
  cerr << "TokenizerFlexLexer::yylex() has been called; shouldn't arrive here." << endl;
  exit(EXIT_FAILURE);
}

